@@ -71,6 +71,12 @@ SCHEME = {
         "#0087ff", "#af005f", "#00afaf", "#e4e4e4",
         "#1c1c1c", "#d75f00", "#585858", "#626262",
         "#808080", "#5f5faf", "#8a8a8a", "#ffffd7"),
+
+    'mint-terminal': (
+        "#2E3436", "#CC0000", "#4E9A06", "#C4A000",
+        "#3465A4", "#75507B", "#06989A", "#D3D7CF",
+        "#555753", "#EF2929", "#8AE234", "#FCE94F",
+        "#729FCF", "#AD7FA8", "#34E2E2", "#EEEEEC"),
     }
 
 
